varying vec4 worldPosition;
varying vec4 viewPosition;
varying vec4 screenPosition;
varying vec3 vertexNormal;
varying vec4 vertexColor;

#define MAX_LIGHTS 16

struct lightSource {
    vec3 position;
    vec3 color;
};

extern lightSource lights[MAX_LIGHTS];

float specularStrength = 0.5;
vec3 ambient = vec3(0.1, 0.1, 0.1);

vec4 effect(vec4 color, Image tex, vec2 tc, vec2 sc) {
    vec3 fragPosition = vec3(worldPosition[0], worldPosition[1], worldPosition[2]);
    vec3 viewPos = vec3(viewPosition[0], viewPosition[1], viewPosition[2]);
    vec3 norm = normalize(vertexNormal);
    vec3 viewDirection = normalize(viewPos - fragPosition);
    vec3 diffuse = ambient;
    vec3 specular = ambient;

    for (int i = 0; i < MAX_LIGHTS; i++) {
        lightSource l = lights[i];
        vec3 lightDirection = normalize(l.position - fragPosition);
        vec3 reflectDirection = reflect(-lightDirection, norm);
        float spec = pow(max(dot(viewDirection, reflectDirection), 0.0), 32.0);
        specular += specularStrength * spec * l.color;
        float diff = max(dot(norm, lightDirection), 0.0);
        diffuse += diff * l.color;
    };
    
    diffuse = clamp(diffuse, 0.0, 1.0);
    return vec4(ambient + diffuse + specular, 1.0);
}