-- GLOBALS
lg = love.graphics
fs = love.filesystem
kb = love.keyboard
lm = love.mouse
random = math.random
noise = love.math.noise
sin = math.sin
cos = math.cos
f = string.format

function love.load()
    g3d = require("g3d")

    cubes = {}
    count = 16
    radius = 10
    for i=1, count do
        local a = (math.pi * 2) / count * i
        x = radius * cos(a)
        y = radius * sin(a)
        cubes[i] = g3d.newModel("cube.obj", nil, {x, y, 0}, {random(), random(), random()})
    end

    lights = {
        {
            position = {0, 0, 0},
            color = {1, 1, 1}
        },
        {
            position = {10, 0, 0},
            color = {1, 0, 0}
        },
        {
            position = {0, 10, 0},
            color = {0, 0, 1}
        },
    }

    g3d.shader:send("lights", lights)

    time = 0
end

function love.update(dt)
    time = time + dt
    if time > math.pi * 2 then time = 0 end
    g3d.camera.firstPersonMovement(dt)

end

function love.mousemoved(x, y, dx, dy)
    g3d.camera.firstPersonLook(dx, dy)

end

function love.draw()
    for i,v in ipairs(cubes) do
        local ox, oy, oz = unpack(v.translation)
        local rx, ry, rz = unpack(v.rotation)
        v:setTransform({ox, oy, sin(time + i) * 5}, {time, time, time})
        v:draw()
    end
end

function love.keypressed(key)
    if key == "escape" then love.event.push("quit") end
end